@@ -2,7 +2,9 @@
 
 __author__ = """Chris Roat"""
 __email__ = "chris.roat@gmail.com"
-__version__ = "0.2.0"
+__version__ = "0.5.0"
 
 from .pystv import *  # noqa
-from .pystv_viz import *  # noqa
+from .transform import *  # noqa
+from .types import *  # noqa
+from .viz import *  # noqa
